@@ -912,7 +912,7 @@ void ssl_init_CheckServers(server_rec *sm, pool *p)
     }
 
     /*
-     * Give out warnings when more than one SSL-aware virtual server uses the
+     * Give out warnings if more than one SSL-aware virtual server uses the
      * same IP:port. This doesn't work because mod_ssl then will always use
      * just the certificate/keys of one virtual host (which one cannot be said
      * easily - but that doesn't matter here).
@@ -924,6 +924,8 @@ void ssl_init_CheckServers(server_rec *sm, pool *p)
         sc = mySrvConfig(s);
         if (!sc->bEnabled)
             continue;
+        if (s->addrs == NULL)
+            continue;
         key = ap_psprintf(sp, "%pA:%u", &s->addrs->host_addr, s->addrs->host_port);
         ps = ssl_ds_table_get(t, key);
         if (ps != NULL) {
