@@ -9,7 +9,7 @@
 */
 
 /* ====================================================================
- * Copyright (c) 1998-2000 Ralf S. Engelschall. All rights reserved.
+ * Copyright (c) 1998-2001 Ralf S. Engelschall. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -407,7 +407,11 @@ static const struct {
     { "G",     NID_givenName              },
     { "S",     NID_surname                },
     { "D",     NID_description            },
+#if SSL_LIBRARY_VERSION >= 0x00907000
+    { "UID",   NID_x500UniqueIdentifier   },
+#else
     { "UID",   NID_uniqueIdentifier       },
+#endif
     { "Email", NID_pkcs9_emailAddress     },
     { NULL,    0                          }
 };
